@@ -42,9 +42,6 @@ class EC2Manager:
             'TERRAFORM_DIRECTORY', os.path.join(os.getcwd(), 'terraform')
         )
         self._template_directory = os.path.join(os.path.dirname(__file__), 'template')
-        self._repo_url = (
-            f'https://{self.github_user}:{self._github_token}@github.com/{self.github_user}/{self.repo}.git'
-        )
         self._max_attempts = int(os.environ.get('MAX_TIMEOUT', 600))
 
         self._github_client = Github(self._github_token)
@@ -61,11 +58,16 @@ class EC2Manager:
             self.github_user = self.github_user or self._config.get('github_username')
             self.repo = self.repo or self._config.get('github_repo')
 
+            self._repo_url = (
+                f'https://{self.github_user}:{self._github_token}@github.com/{self.github_user}/{self.repo}.git'
+            )
             self._aws_default_region = self._config.get('aws_region')
             self._type = self._config.get('type')
             self._vpc_name = self._config.get('vpc_name')
             self._public_subnet_cidr = self._config.get('public_subnet_cidr')
             self._expose_docker_daemons = int(self._config.get('expose_docker_daemons', 0))
+            self._platform = self._config.get('platform', 'amzn2')
+            self._architecture = self._config.get('architecture', 'arm64')
             self._private_subnet_cidr = self._config.get('private_subnet_cidr', '')
             self._instance_names = self._get_instance_names()
             self._instance_repo_updates = self._get_instance_repo_updates()
@@ -210,6 +212,7 @@ class EC2Manager:
                 'NAME': name,
                 'REPO': self.repo,
                 'COMMIT': self._commit,
+                'ENV_FILE_NAME': os.path.basename(instances[name].get('encoded_env_file', {}).get('file_name', '')),
                 'GITHUB_USERNAME': self.github_user,
                 **instances[name].get('envs', {}),
                 **self._get_encoded_envs(instances[name].get('encoded_env_file', {}))
@@ -292,7 +295,9 @@ class EC2Manager:
                     '-var',
                     f'aws_region={self._aws_default_region}',
                     '-var',
-                    f'expose_docker_daemons={self._expose_docker_daemons}',
+                    f'platform={self._platform}',
+                    '-var',
+                    f'architecture={self._architecture}',
                     '-var',
                     f'instances={instances}'
                 ],
@@ -325,7 +330,9 @@ class EC2Manager:
                 '-var',
                 f'aws_region={self._aws_default_region}',
                 '-var',
-                f'expose_docker_daemons={self._expose_docker_daemons}',
+                f'platform={self._platform}',
+                '-var',
+                f'architecture={self._architecture}',
                 '-var',
                 f'instances={instances}'
             ],
@@ -390,6 +397,70 @@ class EC2Manager:
             extra_args=['instance_status_ok']
         )
 
+    def _install_python(self, name):
+        if self._platform == 'amzn2':
+            self.run_command(
+                name,
+                ['sudo yum install python3 -y']
+            )
+        else:
+            raise NotImplemented
+
+    def _install_git(self, name):
+        if self._platform == 'amzn2':
+            self.run_command(
+                name,
+                ['sudo yum install git -y']
+            )
+        else:
+            raise NotImplemented
+
+    def _install_docker(self, name):
+        if self._platform == 'amzn2':
+            self.run_command(
+                name,
+                [
+                    'sudo amazon-linux-extras install docker',
+                    'sudo service docker start',
+                    'sudo usermod -a -G docker ssm-user',
+                    'sudo chkconfig docker on',
+                ])
+        else:
+            raise NotImplemented
+
+    def _install_docker_compose(self, name):
+        if self._platform == 'amzn2':
+            self.run_command(
+                name,
+                [
+                    'sudo curl -L https://github.com/docker/compose/releases/latest/download/docker-compose-$(uname -s)-$(uname -m) -o /usr/local/bin/docker-compose',
+                    'sudo chmod +x /usr/local/bin/docker-compose'
+                ])
+        else:
+            raise NotImplemented
+
+    def _expose_docker_daemon(self, name):
+        if self._expose_docker_daemons:
+            if self._platform == 'amzn2':
+                self.run_command(
+                    name,
+                    [
+                        'sudo mkdir /etc/systemd/system/docker.service.d 2>/dev/null',
+                        r'sudo echo $"[Service]\nExecStart=\nExecStart=/usr/bin/dockerd -H tcp://0.0.0.0:2375 -H unix:///var/run/docker.sock" >> /etc/systemd/system/docker.service.d/override-docker.conf',
+                        'sudo systemctl daemon-reload',
+                        'sudo systemctl restart docker'
+                    ])
+            else:
+                raise NotImplemented
+
+    def _install_dependencies(self, name, data):
+        self._install_git(name)
+        self._install_python(name)
+        self._install_docker(name)
+        self._install_docker_compose(name)
+        self._expose_docker_daemon(name)
+
+
     def get_terraform_outputs(self):
         """
         Gets the output from terraform state.
@@ -510,6 +581,7 @@ class EC2Manager:
 
         # wait for each instance status to be ok
         self._await_instances()
+        self.install_dependencies()
 
     def _set_env_file(self, name, data):
         """
@@ -518,7 +590,7 @@ class EC2Manager:
         :param str name: The name of the instance.
         :param dict data: The instance's data.
         """
-        file_name = self._config['instances'][name].get('encoded_env_file', {}).get('file_name')
+        file_name = data['envs']['ENV_FILE_NAME']
         if file_name:
             self._logger.info(f'{name} setting env file {file_name}...')
 
@@ -526,7 +598,9 @@ class EC2Manager:
             working_directory = self._get_working_directory(data['working_directory'])
             self.run_command(name, [
                 f'cd {working_directory}',
-                f'echo "{env_file_content}" > {file_name}'
+                f'echo "{env_file_content}" > {file_name}',
+                # we set .env as well so that variables in the docker run commands a set as well
+                f'echo "{env_file_content}" > .env'
             ], print_output=False)
 
     def _update_repo(self, name):
@@ -571,6 +645,15 @@ class EC2Manager:
             data['commands']['start'],
         ])
 
+    def install_dependencies(self):
+        """
+        Installs dependencies on the instances.
+        """
+        self._call_on_all(
+            callable_instance=self._install_dependencies,
+            items=self._get_instance_data(),
+        )
+
     def update_repos(self):
         """
         Updates the code in the instance repos.
